@@ -1,8 +1,9 @@
 import abc
 from enum import Enum
 import numpy as np
-from skspatial.objects import Point
-from srbpy.extension import *
+from skspatial.objects import Point,Vector
+from srbpy.extension import rotate2d,length
+from PyAngle import Angle
 
 
 class LeftRightEnum(Enum):
@@ -299,10 +300,21 @@ class PQX(object):
         out : list
             切线单位向量坐标值
         """
-        x0 = self.get_coordinate(pk - delta)[0]
-        y0 = self.get_coordinate(pk - delta)[1]
-        x1 = self.get_coordinate(pk + delta)[0]
-        y1 = self.get_coordinate(pk + delta)[1]
+        if pk == self.end_pk:
+            x0 = self.get_coordinate(pk - delta)[0]
+            y0 = self.get_coordinate(pk - delta)[1]
+            x1 = self.get_coordinate(pk)[0]
+            y1 = self.get_coordinate(pk)[1]
+        elif pk == self.start_pk:
+            x0 = self.get_coordinate(pk)[0]
+            y0 = self.get_coordinate(pk)[1]
+            x1 = self.get_coordinate(pk + delta)[0]
+            y1 = self.get_coordinate(pk + delta)[1]
+        else:
+            x0 = self.get_coordinate(pk - delta)[0]
+            y0 = self.get_coordinate(pk - delta)[1]
+            x1 = self.get_coordinate(pk + delta)[0]
+            y1 = self.get_coordinate(pk + delta)[1]
         ll = np.sqrt((x0 - x1) * (x0 - x1) + (y0 - y1) * (y0 - y1))
         return [(x1 - x0) / ll, (y1 - y0) / ll]
 
@@ -406,7 +418,14 @@ class PQX(object):
         """
         assert pk1 <= pk2
         p1 = Point(list(self.get_coordinate(pk1)))
-        p2 = Point(list(self.get_coordinate(pk2)))
+
+        # 修改了因pk2超过endpk造成的错误 -bill 10.15
+        # p2 = Point(list(self.get_coordinate(pk2)))
+        if abs(pk2-self.end_pk)<1.0e-6:
+            p2 = Point(list(self.get_coordinate(self.end_pk)))
+        else:
+            p2 = Point(list(self.get_coordinate(pk2)))
+        #
         if p1.distance_point(pt) < p2.distance_point(pt):
             return pk1, 0.5 * (pk1 + pk2), p1.distance_point(pt)
         else:
