@@ -8,4 +8,7 @@
   >>> from srbpy.model import Model
 
 """
-from srbpy.model.core import Model
\ No newline at end of file
+
+from srbpy.model.core import Model
+from srbpy.model.core import Bridge
+from srbpy.model.core import Span
